@@ -1,10 +1,7 @@
 /*
-  Copyright (c) 2007 Paolo Capriotti <p.capriotti@gmail.com>
-            
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
+    SPDX-FileCopyrightText: 2007 Paolo Capriotti <p.capriotti@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #ifndef STATS_H
@@ -32,7 +29,7 @@ public:
     
     int score() const;
     
-signals:
+Q_SIGNALS:
     void hitsChanged();
     void missesChanged();
 };
